### Character (PC or NPC)

sub new {
	my ($class, $s, $d, $i) = @_;

	my $self = {
		str => strength->new($s),
		dex => dexterity->new($d),
		int => intelligence->new($i),
	}

	bless $self, $class;
}

sub getStr {
	my ($self) = @_;

	return $self->{str};
}

sub getDex {
	my ($self) = @_;

	return $self->{dex};
}

sub getInt {
	my ($self) = @_;

	return $self->{int};
}

