

sub new {
	my ($class, $s) = @_;

	my $self = {
		stat => $s;	
	}

	bless $self, $class;
}

sub add {

	my ($self, $x) = @_;

	$self->{stat} += $x;

}

sub substract {

	my ($self, $x) = @_;

	$self->{stat} -= $x;

}

sub get {
	my ($self) = @_;

	return $self->{stat};

}
 
sub set {
	my ($self, $s) = @_;

	return $self->{stat} = $s;

}
 
