

sub new {
	my ($class, $x, $y) = @_;

	my $self = {
		xinmap => x,
		yinmap => y
	}

	bless $self, $class;
}

sub addToX {

	my ($self, $x) = @_;

	$self->{x} = $self->{x} + $x;

}

sub addToY {

	my ($self, $y) = @_;

	$self->{y} = $self->{y} + $y;

}


 
